@@ -13,6 +13,7 @@ from PyQt6.QtWidgets import (
     QComboBox,
     QDialog,
     QDialogButtonBox,
+    QFrame,
     QHBoxLayout,
     QLabel,
     QMessageBox,
@@ -52,7 +53,7 @@ def _wrapping_row(button: QCheckBox, text: str) -> QWidget:
     label.mousePressEvent = lambda _ev: button.toggle()
     row = QWidget()
     h = QHBoxLayout(row)
-    h.setContentsMargins(0, 0, 0, 0)
+    h.setContentsMargins(4, 3, 4, 3)
     h.addWidget(button)
     h.addWidget(label, 1)
     return row
@@ -91,8 +92,11 @@ def _build_checklist_scroll(
 ) -> tuple[QScrollArea, list[tuple[str, QCheckBox]]]:
     scroll = QScrollArea()
     scroll.setWidgetResizable(True)
+    scroll.setFrameShape(QFrame.Shape.NoFrame)
     container = QWidget()
     vbox = QVBoxLayout(container)
+    vbox.setSpacing(2)
+    vbox.setContentsMargins(4, 4, 4, 4)
 
     checks: list[tuple[str, QCheckBox]] = []
     for item in items:
@@ -161,6 +165,8 @@ class QtUI(MenuAdminUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
         info = QLabel(text)
         info.setWordWrap(True)
         layout.addWidget(info)
@@ -199,11 +205,14 @@ class QtUI(MenuAdminUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
 
         tabs = QTabWidget()
 
         global_page = QWidget()
         g_layout = QVBoxLayout(global_page)
+        g_layout.setSpacing(10)
         g_label = QLabel(global_text)
         g_label.setWordWrap(True)
         g_layout.addWidget(g_label)
@@ -215,6 +224,7 @@ class QtUI(MenuAdminUI):
 
         user_page = QWidget()
         u_layout = QVBoxLayout(user_page)
+        u_layout.setSpacing(10)
 
         header = QHBoxLayout()
         header.addWidget(QLabel(_("User:")))
